/* crc.cpp -- contains table based CCITT 32 bit CRC function. 
This file is in the Public Domain. 
*/ 

#define CRC_MASK 0xFFFFFFFFL 
#define CRC32_POLYNOMIAL 0xEDB88320L 

#include "def.h" 
#include "crc.h" 

unsigned long int Ccitt32Table [256]; 

/****************************************************************************/ 

/* 
* This routine simply builds the coefficient table used to calculate 
* 32 bit CRC values throughout this program. The 256 long word table 
* has to be set up once when the program starts. Alternatively, the 
* values could be hard coded in, which would offer a miniscule improvement 
* in overall performance of the program. 
*/ 

int CALLTYPE BuildCRCTable(void) 
{ 
int i; 
int j; 
unsigned long value; 


for ( i = 0; i <= 255 ; i++ ) 
{ 
value = i; 
for ( j = 8 ; j > 0; j-- ) 
{ 
if ( value & 1 ) 
value = ( value >> 1 ) ^ CRC32_POLYNOMIAL; 
else 
value >>= 1; 
} 
Ccitt32Table[ i ] = value; 
} 
return 0; 
} 



